' Last updated September 2015 (SyncBackPro V7)

' The following are profile types:
Const EPTError              = 0 ' Error
Const EPTUnknown            = 1 ' Unknown profile type
Const EPTCustom             = 2 ' Custom
Const EPTBackupFromSrc      = 3 ' Backup from source to destination
Const EPTBackupFromDest     = 4 ' Backup from destination to source
Const EPTOldSync            = 5 ' Sync (old style)
Const EPTSmartSync          = 6 ' SmartSync
Const EPTGroup              = 7 ' Group
Const EPTMirrorRight        = 8 ' Mirror from source to destination
Const EPTMirrorLeft         = 9 ' Mirror from destination to source

' The following are differences. This is a bitmask:
Const CDIFF_IDENTICAL       = 0   ' Skipped because of settings or files are identical
Const CDIFF_SIZE            = 1   ' Different sizes
Const CDIFF_HASH            = 2   ' Different hash values
Const CDIFF_DATETIME        = 4   ' Different modification date & time
Const CDIFF_DESTONLY        = 8   ' In right/destination only
Const CDIFF_SRCONLY         = 16  ' In left/source only
Const CDIFF_ATTRIB          = 32  ' Different attributes
Const CDIFF_VERSION         = 64  ' Only the versions exist (will show in Differences window)
Const CDIFF_CASE            = 128 ' File case is different
Const CDIFF_CREATEDATETIME  = 256 ' Different creation date & time
Const CDIFF_NTFSSEC         = 512 ' Different NTFS security

' The following are actions that can be performed on files and folders (note that
' many of these cannot be used with folders):
Const CACTION_ERROR             = 0  ' Skip the file - there was an error
Const CACTION_SKIP              = 1  ' Do nothing, skip/ignore the file
Const CACTION_COPY_TOSOURCE     = 2  ' Copy from right/destination to the left/source
Const CACTION_COPY_TODEST       = 3  ' Copy from left/source to the right/destination
Const CACTION_DELSOURCE         = 4  ' Delete from left/source
Const CACTION_DELDEST           = 5  ' Delete from right/destination
Const CACTION_DELBOTH           = 6  ' Delete left/source & right/destination
Const CACTION_MISSING_PROMPT    = 7  ' A file is in left/source or right/destination, but not both, prompt the user
Const CACTION_DETAILS_PROMPT    = 8  ' Contents same, but attributes and/or date & time changed, prompt the user
Const CACTION_BOTH_PROMPT       = 9  ' The file has changed in both, prompt the user
Const CACTION_USE_SRC_DETAILS   = 10 ' Use the file attributes, security, filename case, and/or date & time from the left/source
Const CACTION_USE_DEST_DETAILS  = 11 ' Use the file attributes, security, filename case, and/or date & time from the right/destination
Const CACTION_MOVE_TOSOURCE     = 12 ' Move from right/destination to the left/source
Const CACTION_MOVE_TODEST       = 13 ' Move from left/source to the right/destination
Const CACTION_UNCHANGED         = 14 ' The file is actually unchanged (for Fast Backup only)
Const CACTION_RENAME_SOURCE     = 15 ' Rename the left/source file (for SmartSync only when the file has been renamed)
Const CACTION_RENAME_DEST       = 16 ' Rename the right/destination file (for SmartSync only when the file has been renamed)
Const CACTION_SKIP_ALWAYS       = 17 ' Same as CACTION_SKIP_ONCE_NOUPD except selections updated so file is unselected
Const CACTION_SKIP_ONCE_NOUPD   = 18 ' Do nothing, skip/ignore the file. SmartSync/Cloud database is NOT updated.

' The following are profile run results:
Const ELR_None                  = 0  ' No result
Const ELR_UnknownProfile        = 1  ' Unknown profile
Const ELR_AlreadyRunning        = 2  ' Profile is already running
Const ELR_Imported              = 3  ' Profile has been imported and not run yet
Const ELR_Running               = 4  ' Profile is running
Const ELR_InternalError         = 5  ' Internal error
Const ELR_SimAborted            = 6  ' Simulated run was aborted
Const ELR_SimFailed             = 7  ' Simulated run failed
Const ELR_SimSuccess            = 8  ' Simulated run was a success
Const ELR_RestAborted           = 9  ' Restore was aborted
Const ELR_RestFailed            = 10 ' Restore failed
Const ELR_RestSuccess           = 11 ' Restore was a success
Const ELR_Aborted               = 12 ' Run was aborted
Const ELR_Failed                = 13 ' Run failed
Const ELR_Success               = 14 ' Run was a success
Const ELR_NetFailed             = 15 ' Failed due to network connection
Const ELR_ScanFailed            = 16 ' Failed because left or right could not be scanned
Const ELR_CompFailed            = 17 ' Failed because the left and right could not be compared
Const ELR_RunBeforeFailed       = 18 ' Run failed because Run Before program stopped profile
Const ELR_Disabled              = 19 ' Run failed because profile is disabled
Const ELR_SMARTFailed           = 20 ' Run failed because drive errors were found
Const ELR_EmailFailed           = 21 ' Run failed because the log could not be emailed
Const ELR_SnapshotFailed        = 22 ' Run failed because the Volume Shadow Copy service failed
Const ELR_TimeLimit             = 23 ' Profile was aborted because it reached its run-time limit
Const ELR_TooManyDeletes        = 24 ' Profile was aborted because too many files would be deleted
Const ELR_BurnFailure           = 25 ' Cannot burn to CD/DVD

' The following are reasons why a file or folder is ignored:
Const EIRUnknown                    = 0  ' Unknown
Const EIRNotSelected                = 1  ' Not select in folder & file selectin tree
Const EIRDoesNotExist               = 2  ' File/folder does not exist
Const EIRJunctionPoint              = 3  ' Is a junction point and settings say they are to be ignored
Const EIRNewFolder                  = 4  ' A new folder and parent folder settings say new folders are to be ignored
Const EIRNewFile                    = 5  ' A new file and parent folder settings say new files are to be ignored
Const EIRFiltered                   = 6  ' Filtered out due to filter settings
Const EIRNotZipFile                 = 7  ' File is not a Zip file (when multi-zip and a non-zip file is found)
Const EIRError                      = 8  ' Skipped due to error
Const EIRNotModifiedWithin          = 9  ' Wasn't modified within the required time
Const EIRSizeOutOfBounds            = 10 ' File size is too small or too large
Const EIRIdentical                  = 11 ' The source & destination file are the same
Const EIRAdvancedSetting            = 12 ' Many reasons, e.g. in destination but not source
Const EIRNotOldEnoughToDelete       = 13 ' Old file (only in source or dest) not deleted as it's not old enough
Const EIRCannotModifySource         = 14 ' Source cannot be modified, e.g. Fast Backup
Const EIROtherFileNewer             = 15 ' The destination file is newer so cannot be replace
Const EIRCannotReplaceReadOnly      = 16 ' The destination file is read-only so cannot be replace
Const EIRCannotDelReadOnly          = 17 ' The destination file is read-only so cannot be deleted
Const EIRCannotMoveCopyReadOnly     = 18 ' Source is read-only so cannot be copied
Const EIRCannotMoveCopyNotAttrib    = 19 ' Source file does not have archive attribute set so cannot be copied
Const EIRCannotMoveCopyHidden       = 20 ' Source file has hidden attribute set so cannot be copied
Const EIRCannotMoveCopySystem       = 21 ' Source file has system attribute set so cannot be copied
Const EIRDST                        = 22 ' Not copied due to DST time difference
Const EIRSameSize                   = 23 ' Files same size
Const EIRScript                     = 24 ' Ignored by script
Const EIRCannotMoveCopyOffline      = 25 ' Source file has offline attribute set so cannot be copied
Const EIRCannotMoveCopyEncrypted    = 26 ' Source file has NTFS encrypted attribute set so cannot be copied
Const EIRCannotModifyDestination    = 27 ' Destination cannot be modified
Const EIRSameTime                   = 28 ' Files same date and time
Const EIRReplacingWithEmpty         = 29 ' Trying to replace a non-empty file with an empty file
Const EIRNotCreatedWithin           = 30 ' Wasn't created within the required time

' The following are location abilities. Note that some of these cannot be
' returned by LocAbilities:
Const CAN_WINDOWSFOLDERS        = 1         ' Does the location use Windows folders? Cannot be used by LocAbilities().
Const CAN_COPYDIRATTRS          = 2         ' Can the directory attributes and date & times be copied to a new directory? Cannot be used by LocAbilities().
Const CAN_COPYSECURITY          = 4         ' Can file/folder NTFS security be copied? Cannot be used by LocAbilities().
Const CAN_USEBACKUPAPI          = 8         ' Can the BackupRead/BackupWrite API's be used? Cannot be used by LocAbilities().
Const CAN_USEMD5                = 16        ' Can use MD5 hashing? Cannot be used by LocAbilities().
Const CAN_USEATTRIBUTES         = 32        ' Do files/folders have Windows filesystem attributes?
Const CAN_EXACTDATETIME         = 64        ' Are file dates & times stored exactly (including milli-seconds)?
Const CAN_CHANGEATTRIBUTES      = 128       ' LEGACY SETTING, use CAN_CHANGE_FILEATTRS and CAN_CHANGE_FOLDERATTRS settings instead
Const CAN_CHANGEDATETIME        = 256       ' Can file/folder last modification date & times be changed?
Const CAN_SINGLEZIP             = 512       ' Are all the files stored in a single Zip file? Cannot be used by LocAbilities().
Const CAN_HAVEEMPTYPATH         = 1024      ' Can the base path be empty?
Const CAN_STOREDONWINDOWS       = 2048      ' Is the location on a Windows filesystem? e.g. a drive or UNC path. Cannot be used by LocAbilities().
Const CAN_VERSION               = 4096      ' Does the location support versioning?
Const CAN_DIRECTACCESS          = 8192      ' Are files stored on a Windows filesystem uncompressed etc? Cannot be used by LocAbilities().
Const CAN_NTFSATTRIBUTES        = 16384     ' Files & folders have NTFS extended attributes?
Const CAN_DRIVELETTER           = 32768     ' Accessed via a drive letter? This is different from CAN_STOREDONWINDOWS because the CD/DVD burner uses a drive letter but you cannot read from it. Cannot be used by LocAbilities().
Const CAN_WRITEONCE             = 65536     ' Write-once, meaning cannot read from it only write to it, e.g. burn location and spanned/split zip
Const CAN_MOVE_FILES            = 131072    ' Can files be moved/renamed?
Const CAN_USECRC32              = 262144    ' Can use CRC32 hashing?
Const CAN_MOVE_FOLDERS          = 524288    ' Can folders be moved/renamed?
Const CAN_PREFERRED_FILECASE    = 1048576   ' It is better to use the case of files on this location
Const CAN_PREFERRED_FOLDERCASE  = 2097152   ' It is better to use the case of folders on this location
Const CAN_CANNOT_COPYTO         = 4194304   ' Files cannot be copied to this location, but can be deleted from it, e.g. backup of email
Const CAN_VIRTUALFOLDERS	= 8388608   ' Folders are virtual and not real so they should not be created, deleted, or renamed, e.g. cloud
Const CAN_RESUME_TRANSFER	= 16777216  ' Can the location resume a broken file transfer if the profile is run again?
Const CAN_CHANGE_FILEATTRS	= 33554432  ' Can file attributes be changed? Normal only
Const CAN_CHANGE_FOLDERATTRS	= 67108864  ' Can folder attributes be changed? Normal and multi-zip only
Const CAN_CHANGE_CACHEDSIZE	= 134217728 ' Can file size be changed? Cloud only. This is used with cloud caching.

' The following are the versions of Windows:
Const WINVER_Unknown        = 0
Const WINVER_Windows2000    = 1  // Windows 5.0
Const WINVER_WindowsXP      = 2  // Windows 5.1
Const WINVER_Windows2003    = 3  // Windows 5.2
Const WINVER_Windows2003R2  = 3  // Windows 5.2
Const WINVER_WindowsHomeSrv = 3  // Windows 5.2
Const WINVER_WindowsXPPro64 = 3  // Windows 5.2
Const WINVER_WindowsVista   = 4  // Windows 6.0
Const WINVER_Windows2008    = 5  // Windows 6.0
Const WINVER_Windows7       = 6  // Windows 6.1
Const WINVER_Windows2008R2  = 7  // Windows 6.1
Const WINVER_Windows8       = 8  // Windows 6.2
Const WINVER_Windows8Server = 9  // Windows 6.2
Const WINVER_Windows2012    = 9  // Windows 6.2
Const WINVER_Windows81      = 10 // Windows 6.3
Const WINVER_Windows2012R2  = 11 // Windows 6.3
Const WINVER_Windows10      = 12 // Windows 6.4
Const WINVER_Windows2016    = 13 // Windows 6.4

' The following are the reasons why a profile was aborted:
Const EAR_User              = 0  ' User chose to stop this profile
Const EAR_Timeup            = 1  ' Profile has run out of time (ELR_TimeLimit)
Const EAR_ProgramClose      = 2  ' SyncBack is closing
Const EAR_StopAllProfiles   = 3  ' User wants to stop all the profiles
Const EAR_WindowsShutdown   = 4  ' Profiles are stopping because of Windows shutdown
Const EAR_StoppingGroup     = 5  ' Stopping because it's part of a group that is being stopped
Const EAR_Script            = 6  ' Aborted by a script
Const EAR_TooManyDeletes    = 7  ' Too many files would be deleted (ELR_TooManyDeletes)
Const EAR_BurnFailure       = 8  ' CD/DVD burn failure (ELR_BurnFailure)
Const EAR_AlreadyRunning    = 9  ' The profile was already running
Const EAR_UserOther         = 10 ' User chose to stop this profile (from another process)

' The following are profile backup types:
Const ERBT_Unknown      = 0
Const ERBT_Full         = 1 ' Full
Const ERBT_Incremental  = 2 ' Incremental
Const ERBT_Differential = 3 ' Differential

' The following are cloud service types:
Const ECT_Unknown   	= 0
Const ECT_S3        	= 1 ' Amazon S3 or compatible
Const ECT_Azure     	= 2 ' Microsoft Azure or compatible
Const ECT_Dropbox   	= 3 ' Dropbox
Const ECT_GDrive    	= 4 ' Google Drive
Const ECT_OneDrive  	= 5 ' Microsoft OneDrive/SkyDrive
Const ECT_SkyDrive  	= 5 ' Microsoft OneDrive/SkyDrive
Const ECT_Box       	= 6 ' Box
Const ECT_CloudDrive	= 7 ' Amazon Cloud Drive
Const ECT_SugarSync	= 8 ' SugarSync
Const ECT_Office365	= 9 ' Office 365 and Sharepoint
